@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.010';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.011';
 use 5.010; use strict; use warnings;
 
 use Carp;
@@ -80,12 +80,12 @@ sub _set_options {
   my ($route, $path, $config) = @_;
 
   my %defaults = (
-    route_root          => '',        template         => 'index.tt',
-    layout              => 'main.tt', header_class     => '',
-    generate_toc        => 0,         linkable_headers => 0,
-    cache               => 1,         dialect          => 'GitHub',
-    exclude_files       => '',        include_files    => '',
-    markdown_extensions => '',        file_root        => 'lib/data/markdown_files',
+    route_root          => '',        template            => 'index.tt',
+    layout              => 'main.tt', header_class        => '',
+    generate_toc        => 0,         linkable_headers    => 0,
+    cache               => 1,         exclude_files       => '',
+    include_files       => '',        markdown_extensions => '',
+    file_root           => 'lib/data/markdown_files',
   );
 
   my %options = ();
@@ -204,16 +204,17 @@ sub mdfile_2html {
     $markdown = <$md>;
     close $md;
   }
-  my $out = markdown($markdown, extensions => HOEDOWN_EXT_FENCED_CODE);
+  my $out  = markdown($markdown, extensions => HOEDOWN_EXT_FENCED_CODE);
+  my $tree = HTML::TreeBuilder->new_from_content($out);
+  _add_single_line_class($tree);
 
   # See if we can cache and return the output without further processing
   # generate_toc makes linkable_headers true so we just need to test linkable_headers option
   if (!$options->{linkable_headers}) {
-    my ($html, $toc) = $s->_cache_data($options, $cache_file, $file, $out);
+    my ($html, $toc) = $s->_cache_data($options, $cache_file, $file, $tree->guts->as_HTML);
     return wantarray ?  ($html, $toc) : $html;
   }
 
-  my $tree     = HTML::TreeBuilder->new_from_content($out);
   my @elements = $tree->look_down(_tag => qr/^h\d$/);
   my $toc      = HTML::TreeBuilder->new();
   my ($base)   = fileparse($file, qr/\.[^.]*/);
@@ -232,21 +233,24 @@ sub mdfile_2html {
     }
   }
 
-  # add a special class for code that has no siblings to give it special styling
-  # TODO: document this
-  my @code_els = $tree->find_by_tag_name('code');
-  foreach my $code_el (@code_els) {
-    if (!$code_el->left && !$code_el->right) {
-      $code_el->attr('class' => 'single-line');
-    }
-  }
-
   # Generate the final HTML from trees and cache
   # "guts" method gets rid of <html> and <body> tags added by TreeBuilder
   return $s->_cache_data($options, $cache_file, $file,
                          $tree->guts->as_HTML, $toc->guts->as_HTML);
 }
 
+# add a special class for code that has no siblings so it can be styled
+sub _add_single_line_class {
+  my $tree = shift;
+  my @code_els = $tree->find_by_tag_name('code');
+  foreach my $code_el (@code_els) {
+    if (!$code_el->left && !$code_el->right) {
+      $code_el->attr('class' => 'single-line');
+    }
+  }
+}
+
+# cache the data
 sub _cache_data {
   my ($s, $options, $cache_file, $file, $content, $toc) = @_;
   $toc //= '';
@@ -272,7 +276,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -294,7 +298,6 @@ the Dancer2 C<config.yml> file:
         linkable_headers: 1                      # create unique id for headers
         template: 'index.tt'                     # template file to use
         layout: 'main.tt'                        # layout file to use
-        dialect: 'GitHub'                        # dialect of markdown file
       routes:                                    # list of conversion routes
         - dzil_tutorial:
             dir: 'Dist-Zilla-for-Beginners'      # dir containing markdown files
@@ -316,7 +319,7 @@ this is plugin, like so:
   # convert a single markdown file to HTML
   $html = mdfile_2html('/path/to/file.md', { header_class => 'header_style' });
 
-  # convert directory of markdown files to HTML and generate taable of contents
+  # convert directory of markdown files to HTML and generate table of contents
   ($html, $toc) = mdfiles_2html('/dir/with/markdown/files', { generate_toc => 1 });
 
 =head1 DESCRIPTION
@@ -376,8 +379,8 @@ configuration file, C<lib/data/markdown_files> is used.
 
 =head2 mdfiles_2html($dir, [ \%options ]  )
 
-Attempts to convert all the files present in a directory to markdown and munges
-them into a single HTML string.
+Attempts to convert all the files present in a directory from markdown into a
+single HTML string.
 
 Example:
 
@@ -445,11 +448,6 @@ C<index.tt> is the default template.
 The layout file to use relative to the app's layout directory C<main.tt> is the
 default layout.
 
-=head3 dialect => $dialect
-
-As markdown has no standard, there are many different dialects. By default, the
-C<GitHub> dialect, as implemented by the Markdent module, is used.
-
 =head3 cache => $bool
 
 Stores generated html in files. If the timestamp of the cached file indicates
@@ -548,6 +546,14 @@ this:
 
 Now only the four files listed get processed in the order listed above.
 
+=head1 MARKDOWN CONVERSION NOTES
+
+The module aims to support the dialect of markdown as implemented by GitHub with
+strikethroughs (C<~~strike~~>) and "fenced" code (C<```fenced code```>). This module
+may make the dialect options configurable in the future.
+
+The module will add a "single-line" class to single lines of code to facility additional styling.
+
 =head1 REQUIRES
 
 =over 4
@@ -626,10 +632,10 @@ See perlmodinstall for information and options on installing Perl modules.
 
 =head1 SEE ALSO
 
-L<Markdent>
-
 L<Dancer2>
 
+L<Text::Markup::Hoedown>
+
 =head1 AUTHOR
 
 Steve Dondley <s@dondley.com>
